/****************************************************************************
** Meta object code from reading C++ file 'archiveinterface.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../archiveinterface/archiveinterface.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'archiveinterface.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN24ReadOnlyArchiveInterfaceE_t {};
} // unnamed namespace

template <> constexpr inline auto ReadOnlyArchiveInterface::qt_create_metaobjectdata<qt_meta_tag_ZN24ReadOnlyArchiveInterfaceE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ReadOnlyArchiveInterface",
        "signalFinished",
        "",
        "PluginFinishType",
        "eType",
        "error",
        "message",
        "details",
        "signalprogress",
        "dPercentage",
        "signalCurFileName",
        "filename",
        "signalFileWriteErrorName",
        "signalQuery",
        "Query*",
        "query",
        "signalCancel"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'signalFinished'
        QtMocHelpers::SignalData<void(PluginFinishType)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'error'
        QtMocHelpers::SignalData<void(const QString &, const QString &)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 6 }, { QMetaType::QString, 7 },
        }}),
        // Signal 'error'
        QtMocHelpers::SignalData<void(const QString &)>(5, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::QString, 6 },
        }}),
        // Signal 'error'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Signal 'signalprogress'
        QtMocHelpers::SignalData<void(double)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 9 },
        }}),
        // Signal 'signalCurFileName'
        QtMocHelpers::SignalData<void(const QString &)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 11 },
        }}),
        // Signal 'signalFileWriteErrorName'
        QtMocHelpers::SignalData<void(const QString &)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 11 },
        }}),
        // Signal 'signalQuery'
        QtMocHelpers::SignalData<void(Query *)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 14, 15 },
        }}),
        // Signal 'signalCancel'
        QtMocHelpers::SignalData<void()>(16, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<ReadOnlyArchiveInterface, qt_meta_tag_ZN24ReadOnlyArchiveInterfaceE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject ReadOnlyArchiveInterface::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN24ReadOnlyArchiveInterfaceE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN24ReadOnlyArchiveInterfaceE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN24ReadOnlyArchiveInterfaceE_t>.metaTypes,
    nullptr
} };

void ReadOnlyArchiveInterface::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ReadOnlyArchiveInterface *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->signalFinished((*reinterpret_cast<std::add_pointer_t<PluginFinishType>>(_a[1]))); break;
        case 1: _t->error((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 2: _t->error((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 3: _t->error(); break;
        case 4: _t->signalprogress((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 5: _t->signalCurFileName((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 6: _t->signalFileWriteErrorName((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 7: _t->signalQuery((*reinterpret_cast<std::add_pointer_t<Query*>>(_a[1]))); break;
        case 8: _t->signalCancel(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< PluginFinishType >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (ReadOnlyArchiveInterface::*)(PluginFinishType )>(_a, &ReadOnlyArchiveInterface::signalFinished, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (ReadOnlyArchiveInterface::*)(const QString & , const QString & )>(_a, &ReadOnlyArchiveInterface::error, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (ReadOnlyArchiveInterface::*)(double )>(_a, &ReadOnlyArchiveInterface::signalprogress, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (ReadOnlyArchiveInterface::*)(const QString & )>(_a, &ReadOnlyArchiveInterface::signalCurFileName, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (ReadOnlyArchiveInterface::*)(const QString & )>(_a, &ReadOnlyArchiveInterface::signalFileWriteErrorName, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (ReadOnlyArchiveInterface::*)(Query * )>(_a, &ReadOnlyArchiveInterface::signalQuery, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (ReadOnlyArchiveInterface::*)()>(_a, &ReadOnlyArchiveInterface::signalCancel, 8))
            return;
    }
}

const QMetaObject *ReadOnlyArchiveInterface::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ReadOnlyArchiveInterface::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN24ReadOnlyArchiveInterfaceE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int ReadOnlyArchiveInterface::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 9)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 9)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    }
    return _id;
}

// SIGNAL 0
void ReadOnlyArchiveInterface::signalFinished(PluginFinishType _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void ReadOnlyArchiveInterface::error(const QString & _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2);
}

// SIGNAL 4
void ReadOnlyArchiveInterface::signalprogress(double _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void ReadOnlyArchiveInterface::signalCurFileName(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void ReadOnlyArchiveInterface::signalFileWriteErrorName(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void ReadOnlyArchiveInterface::signalQuery(Query * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1);
}

// SIGNAL 8
void ReadOnlyArchiveInterface::signalCancel()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}
namespace {
struct qt_meta_tag_ZN25ReadWriteArchiveInterfaceE_t {};
} // unnamed namespace

template <> constexpr inline auto ReadWriteArchiveInterface::qt_create_metaobjectdata<qt_meta_tag_ZN25ReadWriteArchiveInterfaceE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ReadWriteArchiveInterface"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<ReadWriteArchiveInterface, qt_meta_tag_ZN25ReadWriteArchiveInterfaceE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject ReadWriteArchiveInterface::staticMetaObject = { {
    QMetaObject::SuperData::link<ReadOnlyArchiveInterface::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN25ReadWriteArchiveInterfaceE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN25ReadWriteArchiveInterfaceE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN25ReadWriteArchiveInterfaceE_t>.metaTypes,
    nullptr
} };

void ReadWriteArchiveInterface::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ReadWriteArchiveInterface *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *ReadWriteArchiveInterface::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ReadWriteArchiveInterface::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN25ReadWriteArchiveInterfaceE_t>.strings))
        return static_cast<void*>(this);
    return ReadOnlyArchiveInterface::qt_metacast(_clname);
}

int ReadWriteArchiveInterface::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ReadOnlyArchiveInterface::qt_metacall(_c, _id, _a);
    return _id;
}
QT_WARNING_POP
