/****************************************************************************
** Meta object code from reading C++ file 'batchjob.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../source/archivemanager/batchjob.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'batchjob.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN8BatchJobE_t {};
} // unnamed namespace

template <> constexpr inline auto BatchJob::qt_create_metaobjectdata<qt_meta_tag_ZN8BatchJobE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "BatchJob"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<BatchJob, qt_meta_tag_ZN8BatchJobE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject BatchJob::staticMetaObject = { {
    QMetaObject::SuperData::link<ArchiveJob::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8BatchJobE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8BatchJobE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN8BatchJobE_t>.metaTypes,
    nullptr
} };

void BatchJob::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<BatchJob *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *BatchJob::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *BatchJob::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8BatchJobE_t>.strings))
        return static_cast<void*>(this);
    return ArchiveJob::qt_metacast(_clname);
}

int BatchJob::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ArchiveJob::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN15BatchExtractJobE_t {};
} // unnamed namespace

template <> constexpr inline auto BatchExtractJob::qt_create_metaobjectdata<qt_meta_tag_ZN15BatchExtractJobE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "BatchExtractJob",
        "signalCurArchiveName",
        "",
        "strArchiveName",
        "slotHandleSingleJobProgress",
        "dPercentage",
        "slotHandleSingleJobCurFileName",
        "strName",
        "slotHandleSingleJobFinished"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'signalCurArchiveName'
        QtMocHelpers::SignalData<void(const QString &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Slot 'slotHandleSingleJobProgress'
        QtMocHelpers::SlotData<void(double)>(4, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Double, 5 },
        }}),
        // Slot 'slotHandleSingleJobCurFileName'
        QtMocHelpers::SlotData<void(const QString &)>(6, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 7 },
        }}),
        // Slot 'slotHandleSingleJobFinished'
        QtMocHelpers::SlotData<void()>(8, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<BatchExtractJob, qt_meta_tag_ZN15BatchExtractJobE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject BatchExtractJob::staticMetaObject = { {
    QMetaObject::SuperData::link<BatchJob::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15BatchExtractJobE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15BatchExtractJobE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN15BatchExtractJobE_t>.metaTypes,
    nullptr
} };

void BatchExtractJob::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<BatchExtractJob *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->signalCurArchiveName((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 1: _t->slotHandleSingleJobProgress((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 2: _t->slotHandleSingleJobCurFileName((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 3: _t->slotHandleSingleJobFinished(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (BatchExtractJob::*)(const QString & )>(_a, &BatchExtractJob::signalCurArchiveName, 0))
            return;
    }
}

const QMetaObject *BatchExtractJob::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *BatchExtractJob::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15BatchExtractJobE_t>.strings))
        return static_cast<void*>(this);
    return BatchJob::qt_metacast(_clname);
}

int BatchExtractJob::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = BatchJob::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 4)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 4)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 4;
    }
    return _id;
}

// SIGNAL 0
void BatchExtractJob::signalCurArchiveName(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}
QT_WARNING_POP
