/****************************************************************************
** Meta object code from reading C++ file 'calculatesizethread.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../source/common/calculatesizethread.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'calculatesizethread.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN19CalculateSizeThreadE_t {};
} // unnamed namespace

template <> constexpr inline auto CalculateSizeThread::qt_create_metaobjectdata<qt_meta_tag_ZN19CalculateSizeThreadE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "CalculateSizeThread",
        "signalFinishCalculateSize",
        "",
        "size",
        "strArchiveFullPath",
        "QList<FileEntry>",
        "listAddEntry",
        "CompressOptions",
        "stOptions",
        "listAllEntry",
        "signalError",
        "strError",
        "strToolTip"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'signalFinishCalculateSize'
        QtMocHelpers::SignalData<void(qint64, QString, QList<FileEntry>, CompressOptions, QList<FileEntry>)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::LongLong, 3 }, { QMetaType::QString, 4 }, { 0x80000000 | 5, 6 }, { 0x80000000 | 7, 8 },
            { 0x80000000 | 5, 9 },
        }}),
        // Signal 'signalError'
        QtMocHelpers::SignalData<void(const QString &, const QString &)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 11 }, { QMetaType::QString, 12 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<CalculateSizeThread, qt_meta_tag_ZN19CalculateSizeThreadE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject CalculateSizeThread::staticMetaObject = { {
    QMetaObject::SuperData::link<QThread::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19CalculateSizeThreadE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19CalculateSizeThreadE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN19CalculateSizeThreadE_t>.metaTypes,
    nullptr
} };

void CalculateSizeThread::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<CalculateSizeThread *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->signalFinishCalculateSize((*reinterpret_cast<std::add_pointer_t<qint64>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QList<FileEntry>>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<CompressOptions>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QList<FileEntry>>>(_a[5]))); break;
        case 1: _t->signalError((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 3:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< CompressOptions >(); break;
            case 4:
            case 2:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QList<FileEntry> >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (CalculateSizeThread::*)(qint64 , QString , QList<FileEntry> , CompressOptions , QList<FileEntry> )>(_a, &CalculateSizeThread::signalFinishCalculateSize, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (CalculateSizeThread::*)(const QString & , const QString & )>(_a, &CalculateSizeThread::signalError, 1))
            return;
    }
}

const QMetaObject *CalculateSizeThread::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *CalculateSizeThread::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19CalculateSizeThreadE_t>.strings))
        return static_cast<void*>(this);
    return QThread::qt_metacast(_clname);
}

int CalculateSizeThread::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QThread::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 2)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 2)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    }
    return _id;
}

// SIGNAL 0
void CalculateSizeThread::signalFinishCalculateSize(qint64 _t1, QString _t2, QList<FileEntry> _t3, CompressOptions _t4, QList<FileEntry> _t5)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2, _t3, _t4, _t5);
}

// SIGNAL 1
void CalculateSizeThread::signalError(const QString & _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2);
}
QT_WARNING_POP
